Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::concepts::Movable Member List

This is the complete list of members for ranges::v3::concepts::Movable, including all inherited members.

base_concepts_t typedef (defined in ranges::v3::concepts::refines< MoveConstructible >) | ranges::v3::concepts::refines< MoveConstructible > |
concepts::model_of() (defined in ranges::v3::concepts::Movable) | ranges::v3::concepts::Movable |
concepts::model_of())) (defined in ranges::v3::concepts::Movable) | ranges::v3::concepts::Movable |
refines()=delete (defined in ranges::v3::concepts::refines< MoveConstructible >) | ranges::v3::concepts::refines< MoveConstructible > |
requires_() -> decltype(concepts::valid_expr(concepts::is_true(std::is_object< T > (defined in ranges::v3::concepts::Movable) | ranges::v3::concepts::Movable |